Created
May 22, 2017 06:20
-
-
Save hughperkins/785b0009bcbb3635d982c109d84e9f69 to your computer and use it in GitHub Desktop.
This file contains hidden or bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
| (env3) ~/coriander/build (llvm-4.0|△2) $ rm -Rf * | |
| (env3) ~/coriander/build (llvm-4.0|△2) $ cmake .. -DBUILD_TESTS=ON -DCLANG_HOME=/usr/local/opt/llvm-4.0 -DCOCL_SPAM=ON | |
| -- The C compiler identification is AppleClang 8.1.0.8020042 | |
| -- The CXX compiler identification is AppleClang 8.1.0.8020042 | |
| -- Check for working C compiler: /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc | |
| -- Check for working C compiler: /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc -- works | |
| -- Detecting C compiler ABI info | |
| -- Detecting C compiler ABI info - done | |
| -- Detecting C compile features | |
| -- Detecting C compile features - done | |
| -- Check for working CXX compiler: /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ | |
| -- Check for working CXX compiler: /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ -- works | |
| -- Detecting CXX compiler ABI info | |
| -- Detecting CXX compiler ABI info - done | |
| -- Detecting CXX compile features | |
| -- Detecting CXX compile features - done | |
| -- Configuring done | |
| CMake Warning (dev): | |
| Policy CMP0042 is not set: MACOSX_RPATH is enabled by default. Run "cmake | |
| --help-policy CMP0042" for policy details. Use the cmake_policy command to | |
| set the policy and suppress this warning. | |
| MACOSX_RPATH is not specified for the following targets: | |
| clblast | |
| clew | |
| cocl | |
| cocl_gtest | |
| easycl | |
| This warning is for project developers. Use -Wno-dev to suppress it. | |
| -- Generating done | |
| -- Build files have been written to: /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/build | |
| (env3) ~/coriander/build (llvm-4.0|△2) $ make -j 8 run-cuda_sample | |
| Scanning dependencies of target clew | |
| Scanning dependencies of target patch_hostside | |
| [ 0%] Building C object CMakeFiles/clew.dir/src/EasyCL/thirdparty/clew/src/clew.c.o | |
| [ 2%] Building CXX object CMakeFiles/patch_hostside.dir/src/readIR.cpp.o | |
| [ 2%] Building CXX object CMakeFiles/patch_hostside.dir/third_party/argparsecpp/argparsecpp.cpp.o | |
| [ 2%] Building CXX object CMakeFiles/patch_hostside.dir/src/struct_clone.cpp.o | |
| [ 5%] Building CXX object CMakeFiles/patch_hostside.dir/src/patch_hostside.cpp.o | |
| [ 5%] Building CXX object CMakeFiles/patch_hostside.dir/src/mutations.cpp.o | |
| [ 7%] Building CXX object CMakeFiles/patch_hostside.dir/src/GlobalNames.cpp.o | |
| [ 7%] Building CXX object CMakeFiles/patch_hostside.dir/src/type_dumper.cpp.o | |
| [ 10%] Linking C shared library libclew.dylib | |
| [ 10%] Built target clew | |
| Scanning dependencies of target clblast | |
| [ 12%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/database/database.cpp.o | |
| Scanning dependencies of target easycl | |
| [ 12%] Building CXX object CMakeFiles/easycl.dir/src/EasyCL/CLKernel.cpp.o | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/struct_clone.cpp:228:72: warning: implicit | |
| conversion turns string literal into bool: 'const char [9]' to 'bool' [-Wstring-conversion] | |
| Instruction *store = new StoreInst(load, childDstInst, "storeint"); | |
| ~~~~~~~~~ ^~~~~~~~~~ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/struct_clone.cpp:250:72: warning: implicit | |
| conversion turns string literal into bool: 'const char [9]' to 'bool' [-Wstring-conversion] | |
| Instruction *store = new StoreInst(load, arraydst, "storearr"); | |
| ~~~~~~~~~ ^~~~~~~~~~ | |
| [ 12%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/common.cpp.o | |
| [ 15%] Building CXX object CMakeFiles/easycl.dir/src/EasyCL/CLWrapper.cpp.o | |
| [ 15%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/cache.cpp.o | |
| [ 15%] Building CXX object CMakeFiles/patch_hostside.dir/src/EasyCL/util/easycl_stringhelper.cpp.o | |
| [ 15%] Building CXX object CMakeFiles/easycl.dir/src/EasyCL/platforminfo_helper.cpp.o | |
| [ 17%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/clblast.cpp.o | |
| [ 20%] Building CXX object CMakeFiles/easycl.dir/src/EasyCL/EasyCL.cpp.o | |
| [ 20%] Building CXX object CMakeFiles/easycl.dir/src/EasyCL/deviceinfo_helper.cpp.o | |
| 2 warnings generated. | |
| [ 20%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/clblast_c.cpp.o | |
| [ 20%] Building CXX object CMakeFiles/easycl.dir/src/EasyCL/util/easycl_stringhelper.cpp.o | |
| [ 20%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routine.cpp.o | |
| [ 23%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/utilities.cpp.o | |
| [ 23%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level1/xswap.cpp.o | |
| [ 25%] Building CXX object CMakeFiles/easycl.dir/src/EasyCL/DevicesInfo.cpp.o | |
| [ 28%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level1/xscal.cpp.o | |
| [ 28%] Building CXX object CMakeFiles/easycl.dir/src/EasyCL/DeviceInfo.cpp.o | |
| [ 30%] Linking CXX executable patch_hostside | |
| [ 30%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level1/xcopy.cpp.o | |
| [ 30%] Built target patch_hostside | |
| [ 30%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level1/xaxpy.cpp.o | |
| [ 33%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level1/xdot.cpp.o | |
| [ 33%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level1/xdotu.cpp.o | |
| [ 33%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level1/xdotc.cpp.o | |
| [ 35%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level1/xnrm2.cpp.o | |
| [ 35%] Linking CXX shared library libeasycl.dylib | |
| [ 35%] Built target easycl | |
| [ 35%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level1/xasum.cpp.o | |
| [ 35%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level1/xamax.cpp.o | |
| [ 38%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level2/xgemv.cpp.o | |
| [ 38%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level2/xgbmv.cpp.o | |
| [ 41%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level2/xhemv.cpp.o | |
| [ 41%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level2/xhbmv.cpp.o | |
| [ 41%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level2/xhpmv.cpp.o | |
| [ 43%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level2/xsymv.cpp.o | |
| [ 43%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level2/xsbmv.cpp.o | |
| [ 43%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level2/xspmv.cpp.o | |
| [ 46%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level2/xtrmv.cpp.o | |
| [ 46%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level2/xtbmv.cpp.o | |
| [ 46%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level2/xtpmv.cpp.o | |
| [ 48%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level2/xger.cpp.o | |
| [ 48%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level2/xgeru.cpp.o | |
| [ 51%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level2/xgerc.cpp.o | |
| [ 51%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level2/xher.cpp.o | |
| [ 51%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level2/xhpr.cpp.o | |
| [ 53%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level2/xher2.cpp.o | |
| [ 53%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level2/xhpr2.cpp.o | |
| [ 53%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level2/xsyr.cpp.o | |
| [ 56%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level2/xspr.cpp.o | |
| [ 56%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level2/xsyr2.cpp.o | |
| [ 56%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level2/xspr2.cpp.o | |
| [ 58%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level3/xgemm.cpp.o | |
| [ 58%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level3/xsymm.cpp.o | |
| [ 61%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level3/xhemm.cpp.o | |
| [ 61%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level3/xsyrk.cpp.o | |
| [ 61%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level3/xherk.cpp.o | |
| [ 64%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level3/xsyr2k.cpp.o | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/CLBlast/src/routines/level3/xsymm.cpp:111:16: warning: | |
| 27 enumeration values not handled in switch: 'kKernelLaunchError', 'kKernelRunError', | |
| 'kInvalidLocalMemUsage'... [-Wswitch] | |
| switch(status) { | |
| ^ | |
| [ 64%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level3/xher2k.cpp.o | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/CLBlast/src/routines/level3/xsymm.cpp:111:16: warning: | |
| 27 enumeration values not handled in switch: 'kKernelLaunchError', 'kKernelRunError', | |
| 'kInvalidLocalMemUsage'... [-Wswitch] | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/CLBlast/src/routines/level3/xsymm.cpp:111:16: warning: | |
| 27 enumeration values not handled in switch: 'kKernelLaunchError', 'kKernelRunError', | |
| 'kInvalidLocalMemUsage'... [-Wswitch] | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/CLBlast/src/routines/level3/xsymm.cpp:111:16: warning: | |
| 27 enumeration values not handled in switch: 'kKernelLaunchError', 'kKernelRunError', | |
| 'kInvalidLocalMemUsage'... [-Wswitch]/Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/CLBlast/src/routines/level3/xhemm.cpp:111:16: warning: | |
| 27 enumeration values not handled in switch: 'kKernelLaunchError', 'kKernelRunError', | |
| 'kInvalidLocalMemUsage'... [-Wswitch] | |
| switch(status) { | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/CLBlast/src/routines/level3/xsymm.cpp:111:16: warning: | |
| 27 enumeration values not handled in switch: 'kKernelLaunchError', 'kKernelRunError', | |
| 'kInvalidLocalMemUsage'... [-Wswitch] | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/CLBlast/src/routines/level3/xhemm.cpp:111:16: warning: | |
| 27 enumeration values not handled in switch: 'kKernelLaunchError', 'kKernelRunError', | |
| 'kInvalidLocalMemUsage'... [-Wswitch] | |
| 2 warnings generated. | |
| [ 64%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/level3/xtrmm.cpp.o | |
| 5 warnings generated. | |
| [ 66%] Building CXX object CMakeFiles/clblast.dir/src/CLBlast/src/routines/levelx/xomatcopy.cpp.o | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/CLBlast/src/routines/level3/xtrmm.cpp:114:16: warning: | |
| 27 enumeration values not handled in switch: 'kKernelLaunchError', 'kKernelRunError', | |
| 'kInvalidLocalMemUsage'... [-Wswitch] | |
| switch(status) { | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/CLBlast/src/routines/level3/xtrmm.cpp:114:16: warning: | |
| 27 enumeration values not handled in switch: 'kKernelLaunchError', 'kKernelRunError', | |
| 'kInvalidLocalMemUsage'... [-Wswitch] | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/CLBlast/src/routines/level3/xtrmm.cpp:114:16: warning: | |
| 27 enumeration values not handled in switch: 'kKernelLaunchError', 'kKernelRunError', | |
| 'kInvalidLocalMemUsage'... [-Wswitch] | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/CLBlast/src/routines/level3/xtrmm.cpp:114:16: warning: | |
| 27 enumeration values not handled in switch: 'kKernelLaunchError', 'kKernelRunError', | |
| 'kInvalidLocalMemUsage'... [-Wswitch] | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/CLBlast/src/routines/level3/xtrmm.cpp:114:16: warning: | |
| 27 enumeration values not handled in switch: 'kKernelLaunchError', 'kKernelRunError', | |
| 'kInvalidLocalMemUsage'... [-Wswitch] | |
| 5 warnings generated. | |
| [ 66%] Linking CXX shared library libclblast.dylib | |
| [ 66%] Built target clblast | |
| Scanning dependencies of target cocl | |
| [ 66%] Building CXX object CMakeFiles/cocl.dir/src/type_dumper.cpp.o | |
| [ 66%] Building CXX object CMakeFiles/cocl.dir/src/LocalNames.cpp.o | |
| [ 69%] Building CXX object CMakeFiles/cocl.dir/src/new_instruction_dumper.cpp.o | |
| [ 71%] Building CXX object CMakeFiles/cocl.dir/src/basicblockdumper.cpp.o | |
| [ 71%] Building CXX object CMakeFiles/cocl.dir/src/GlobalNames.cpp.o | |
| [ 71%] Building CXX object CMakeFiles/cocl.dir/src/struct_clone.cpp.o | |
| [ 71%] Building CXX object CMakeFiles/cocl.dir/src/ExpressionsHelper.cpp.o | |
| [ 74%] Building CXX object CMakeFiles/cocl.dir/src/readIR.cpp.o | |
| [ 74%] Building CXX object CMakeFiles/cocl.dir/src/function_names_map.cpp.o | |
| [ 74%] Building CXX object CMakeFiles/cocl.dir/src/function_dumper.cpp.o | |
| [ 76%] Building CXX object CMakeFiles/cocl.dir/src/kernel_dumper.cpp.o | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/struct_clone.cpp:228:72: warning: implicit | |
| conversion turns string literal into bool: 'const char [9]' to 'bool' [-Wstring-conversion] | |
| Instruction *store = new StoreInst(load, childDstInst, "storeint"); | |
| ~~~~~~~~~ ^~~~~~~~~~ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/struct_clone.cpp:250:72: warning: implicit | |
| conversion turns string literal into bool: 'const char [9]' to 'bool' [-Wstring-conversion] | |
| Instruction *store = new StoreInst(load, arraydst, "storearr"); | |
| ~~~~~~~~~ ^~~~~~~~~~ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/new_instruction_dumper.cpp:700:20: warning: | |
| unused variable 'operand' [-Wunused-variable] | |
| Value *operand = instr->getOperand(d); | |
| ^ | |
| [ 76%] Building CXX object CMakeFiles/cocl.dir/src/mutations.cpp.o | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/new_instruction_dumper.cpp:1139:29: warning: | |
| clang 4 detected [-W#pragma-messages] | |
| #pragma message("clang 4 detected") | |
| ^ | |
| [ 79%] Building CXX object CMakeFiles/cocl.dir/third_party/argparsecpp/argparsecpp.cpp.o | |
| [ 79%] Building CXX object CMakeFiles/cocl.dir/src/cocl_dnn.cpp.o | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/function_dumper.cpp:469:14: warning: unused | |
| variable 'ispointer' [-Wunused-variable] | |
| bool ispointer = isa<PointerType>(argType); | |
| ^ | |
| 2 warnings generated. | |
| [ 79%] Building CXX object CMakeFiles/cocl.dir/src/cocl_dnn_gemm.cpp.o | |
| [ 82%] Building CXX object CMakeFiles/cocl.dir/src/cocl_dnn_pooling.cpp.o | |
| [ 82%] Building CXX object CMakeFiles/cocl.dir/src/cocl_dnn_conv.cpp.o | |
| In file included from /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/cocl_dnn.cpp:6: | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:4:9: warning: defining device | |
| and host [-W#pragma-messages] | |
| #pragma message("defining device and host") | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:23:9: warning: '__host__' | |
| macro redefined [-Wmacro-redefined] | |
| #define __host__ | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:6:9: note: previous | |
| definition is here | |
| #define __host__ __attribute__((host)) | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:24:9: warning: '__device__' | |
| macro redefined [-Wmacro-redefined] | |
| #define __device__ | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:5:9: note: previous | |
| definition is here | |
| #define __device__ __attribute__((device)) | |
| ^ | |
| In file included from /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/cocl_dnn.cpp:6: | |
| In file included from /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:44: | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:5:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:5:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:6:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4(float x, float y, float z, float w) : x(x), y... | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:6:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4(float x, float y, float z, float w) : x(x), y... | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:16:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:16:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:17:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2(float x, float y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:17:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2(float x, float y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:24:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:24:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:25:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2(double x, double y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:25:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2(double x, double y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:30:40: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4 make_float4(float x, float y, float z, float w); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:30:16: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4 make_float4(float x, float y, float z, float w); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:31:40: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2 make_float2(float x, float y); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:31:16: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2 make_float2(float x, float y); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:32:40: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2 make_double2(double x, double y); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:32:16: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2 make_double2(double x, double y); | |
| ^ | |
| [ 82%] Building CXX object CMakeFiles/cocl.dir/src/cocl_dnn_act.cpp.o | |
| In file included from /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/cocl_dnn_gemm.cpp:11: | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:4:9: warning: defining device | |
| and host [-W#pragma-messages] | |
| #pragma message("defining device and host") | |
| ^ | |
| 21 warnings generated. | |
| [ 84%] Building CXX object CMakeFiles/cocl.dir/src/hostside_opencl_funcs.cpp.o | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:23:9: warning: '__host__' | |
| macro redefined [-Wmacro-redefined] | |
| #define __host__ | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:6:9: note: previous | |
| definition is here | |
| #define __host__ __attribute__((host)) | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:24:9: warning: '__device__' | |
| macro redefined [-Wmacro-redefined] | |
| #define __device__ | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:5:9: note: previous | |
| definition is here | |
| #define __device__ __attribute__((device)) | |
| ^ | |
| In file included from /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/cocl_dnn_gemm.cpp:11: | |
| In file included from /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:44: | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:5:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:5:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:6:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4(float x, float y, float z, float w) : x(x), y... | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:6:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4(float x, float y, float z, float w) : x(x), y... | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:16:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:16:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:17:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2(float x, float y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:17:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2(float x, float y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:24:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:24:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:25:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2(double x, double y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:25:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2(double x, double y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:30:40: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4 make_float4(float x, float y, float z, float w); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:30:16: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4 make_float4(float x, float y, float z, float w); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:31:40: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2 make_float2(float x, float y); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:31:16: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2 make_float2(float x, float y); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:32:40: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2 make_double2(double x, double y); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:32:16: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2 make_double2(double x, double y); | |
| ^ | |
| In file included from /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/cocl_dnn_pooling.cpp:6: | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:4:9: warning: defining device | |
| and host [-W#pragma-messages] | |
| #pragma message("defining device and host") | |
| ^ | |
| In file included from /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/cocl_dnn_conv.cpp:7: | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:4:9: warning: defining device | |
| and host [-W#pragma-messages] | |
| #pragma message("defining device and host") | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:23:9: warning: '__host__' | |
| macro redefined [-Wmacro-redefined] | |
| #define __host__ | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:6:9: note: previous | |
| definition is here | |
| #define __host__ __attribute__((host)) | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:24:9: warning: '__device__' | |
| macro redefined [-Wmacro-redefined] | |
| #define __device__ | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:5:9: note: previous | |
| definition is here | |
| #define __device__ __attribute__((device)) | |
| ^ | |
| In file included from /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/cocl_dnn_pooling.cpp:6: | |
| In file included from /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:44: | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:5:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:5:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:6:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4(float x, float y, float z, float w) : x(x), y... | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:6:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4(float x, float y, float z, float w) : x(x), y... | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:16:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:16:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:17:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2(float x, float y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:17:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2(float x, float y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:24:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:24:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:25:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2(double x, double y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:25:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2(double x, double y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:30:40: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4 make_float4(float x, float y, float z, float w); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:30:16: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4 make_float4(float x, float y, float z, float w); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:31:40: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2 make_float2(float x, float y); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:31:16: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2 make_float2(float x, float y); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:32:40: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2 make_double2(double x, double y); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:32:16: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2 make_double2(double x, double y); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:23:9: warning: '__host__' | |
| macro redefined [-Wmacro-redefined] | |
| #define __host__ | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:6:9: note: previous | |
| definition is here | |
| #define __host__ __attribute__((host)) | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:24:9: warning: '__device__' | |
| macro redefined [-Wmacro-redefined] | |
| #define __device__ | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:5:9: note: previous | |
| definition is here | |
| #define __device__ __attribute__((device)) | |
| ^ | |
| In file included from /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/cocl_dnn_conv.cpp:7: | |
| In file included from /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:44: | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:5:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:5:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:6:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4(float x, float y, float z, float w) : x(x), y... | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:6:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4(float x, float y, float z, float w) : x(x), y... | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:16:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:16:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:17:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2(float x, float y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:17:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2(float x, float y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:24:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:24:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:25:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2(double x, double y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:25:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2(double x, double y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:30:40: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4 make_float4(float x, float y, float z, float w); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:30:16: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4 make_float4(float x, float y, float z, float w); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:31:40: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2 make_float2(float x, float y); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:31:16: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2 make_float2(float x, float y); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:32:40: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2 make_double2(double x, double y); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:32:16: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2 make_double2(double x, double y); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/cocl_dnn_conv.cpp:92:9: warning: default | |
| label in switch which covers all enumeration values [-Wcovered-switch-default] | |
| default: | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/cocl_dnn_conv.cpp:120:9: warning: default | |
| label in switch which covers all enumeration values [-Wcovered-switch-default] | |
| default: | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/cocl_dnn_conv.cpp:141:9: warning: default | |
| label in switch which covers all enumeration values [-Wcovered-switch-default] | |
| default: | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/cocl_dnn_conv.cpp:161:9: warning: default | |
| label in switch which covers all enumeration values [-Wcovered-switch-default] | |
| default: | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/cocl_dnn_conv.cpp:190:9: warning: default | |
| label in switch which covers all enumeration values [-Wcovered-switch-default] | |
| default: | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/cocl_dnn_conv.cpp:237:9: warning: default | |
| label in switch which covers all enumeration values [-Wcovered-switch-default] | |
| default: | |
| ^ | |
| 21 warnings generated. | |
| 21 warnings generated. | |
| [ 84%] Building CXX object CMakeFiles/cocl.dir/src/cocl_events.cpp.o | |
| [ 84%] Building CXX object CMakeFiles/cocl.dir/src/cocl_blas.cpp.o | |
| In file included from /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/cocl_dnn_act.cpp:6: | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:4:9: warning: defining device | |
| and host [-W#pragma-messages] | |
| #pragma message("defining device and host") | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:23:9: warning: '__host__' | |
| macro redefined [-Wmacro-redefined] | |
| #define __host__ | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:6:9: note: previous | |
| definition is here | |
| #define __host__ __attribute__((host)) | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:24:9: warning: '__device__' | |
| macro redefined [-Wmacro-redefined] | |
| #define __device__ | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:5:9: note: previous | |
| definition is here | |
| #define __device__ __attribute__((device)) | |
| ^ | |
| 27 warnings generated. | |
| In file included from /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/cocl_dnn_act.cpp:6: | |
| In file included from /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:44: | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:5:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:5:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:6:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4(float x, float y, float z, float w) : x(x), y... | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:6:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4(float x, float y, float z, float w) : x(x), y... | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:16:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:16:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:17:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2(float x, float y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:17:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2(float x, float y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:24:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:24:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:25:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2(double x, double y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:25:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2(double x, double y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:30:40: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4 make_float4(float x, float y, float z, float w); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:30:16: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4 make_float4(float x, float y, float z, float w); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:31:40: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2 make_float2(float x, float y); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:31:16: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2 make_float2(float x, float y); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:32:40: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2 make_double2(double x, double y); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:32:16: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2 make_double2(double x, double y); | |
| ^ | |
| In file included from /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/hostside_opencl_funcs.cpp:17: | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:4:9: warning: defining device | |
| and host [-W#pragma-messages] | |
| #pragma message("defining device and host") | |
| ^ | |
| [ 87%] Building CXX object CMakeFiles/cocl.dir/src/cocl_device.cpp.o | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:23:9: warning: '__host__' | |
| macro redefined [-Wmacro-redefined] | |
| #define __host__ | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:6:9: note: previous | |
| definition is here | |
| #define __host__ __attribute__((host)) | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:24:9: warning: '__device__' | |
| macro redefined [-Wmacro-redefined] | |
| #define __device__ | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:5:9: note: previous | |
| definition is here | |
| #define __device__ __attribute__((device)) | |
| ^ | |
| In file included from /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/hostside_opencl_funcs.cpp:17: | |
| In file included from /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:44: | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:5:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:5:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:6:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4(float x, float y, float z, float w) : x(x), y... | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:6:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4(float x, float y, float z, float w) : x(x), y... | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:16:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:16:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:17:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2(float x, float y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:17:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2(float x, float y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:24:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:24:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:25:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2(double x, double y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:25:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2(double x, double y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:30:40: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4 make_float4(float x, float y, float z, float w); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:30:16: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4 make_float4(float x, float y, float z, float w); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:31:40: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2 make_float2(float x, float y); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:31:16: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2 make_float2(float x, float y); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:32:40: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2 make_double2(double x, double y); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:32:16: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2 make_double2(double x, double y); | |
| ^ | |
| 21 warnings generated. | |
| [ 87%] Building CXX object CMakeFiles/cocl.dir/src/cocl_error.cpp.o | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/cocl_error.cpp:22:9: warning: 'COCL_PRINT' | |
| macro redefined [-Wmacro-redefined] | |
| #define COCL_PRINT(x) | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl_defs.h:4:9: note: previous | |
| definition is here | |
| #define COCL_PRINT(expr) \ | |
| ^ | |
| 1 warning generated. | |
| [ 89%] Building CXX object CMakeFiles/cocl.dir/src/cocl_memory.cpp.o | |
| [ 89%] Building CXX object CMakeFiles/cocl.dir/src/cocl_properties.cpp.o | |
| [ 89%] Building CXX object CMakeFiles/cocl.dir/src/cocl_streams.cpp.o | |
| 2 warnings generated. | |
| [ 92%] Building CXX object CMakeFiles/cocl.dir/src/cocl_clsources.cpp.o | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/hostside_opencl_funcs.cpp:331:22: warning: | |
| comparison of integers of different signs: 'int' and 'size_type' (aka 'unsigned long') [-Wsign-compare] | |
| for(int i = 0; i < clmemIndexByClmemArgIndex.size(); i++) { | |
| ~ ^ ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/hostside_opencl_funcs.cpp:554:22: warning: | |
| comparison of integers of different signs: 'int' and 'size_type' (aka 'unsigned long') [-Wsign-compare] | |
| for(int i = 0; i < launchConfiguration.clmems.size(); i++) { | |
| ~ ^ ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/hostside_opencl_funcs.cpp:558:22: warning: | |
| comparison of integers of different signs: 'int' and 'size_type' (aka 'unsigned long') [-Wsign-compare] | |
| for(int i = 0; i < launchConfiguration.args.size(); i++) { | |
| ~ ^ ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ | |
| [ 92%] Building CXX object CMakeFiles/cocl.dir/src/cocl_context.cpp.o | |
| [ 92%] Building CXX object CMakeFiles/cocl.dir/src/ir-to-opencl.cpp.o | |
| [ 94%] Building CXX object CMakeFiles/cocl.dir/src/shims.cpp.o | |
| [ 94%] Building CXX object CMakeFiles/cocl.dir/src/LocalValueInfo.cpp.o | |
| 1 warning generated. | |
| [ 94%] Building CXX object CMakeFiles/cocl.dir/src/ClWriter.cpp.o | |
| [ 97%] Building CXX object CMakeFiles/cocl.dir/src/cocl_vector_types.cpp.o | |
| In file included from /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/cocl_vector_types.cpp:1: | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:5:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:5:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:6:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4(float x, float y, float z, float w) : x(x), y... | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:6:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4(float x, float y, float z, float w) : x(x), y... | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:16:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:16:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:17:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2(float x, float y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:17:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2(float x, float y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:24:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:24:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2() {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:25:44: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2(double x, double y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:25:20: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2(double x, double y) : x(x), y(y) {} | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:30:40: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4 make_float4(float x, float y, float z, float w); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:30:16: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float4 make_float4(float x, float y, float z, float w); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:31:40: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2 make_float2(float x, float y); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:31:16: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) float2 make_float2(float x, float y); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:32:40: warning: | |
| 'host' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2 make_double2(double x, double y); | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/vector_types.h:32:16: warning: | |
| 'device' attribute ignored [-Wignored-attributes] | |
| __attribute__((device)) __attribute__((host)) double2 make_double2(double x, double y); | |
| ^ | |
| 18 warnings generated. | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/cocl_context.cpp:35:9: warning: 'COCL_PRINT' | |
| macro redefined [-Wmacro-redefined] | |
| #define COCL_PRINT(x) | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl_defs.h:4:9: note: previous | |
| definition is here | |
| #define COCL_PRINT(expr) \ | |
| ^ | |
| 1 warning generated. | |
| 24 warnings generated. | |
| [ 97%] Linking CXX shared library libcocl.dylib | |
| [ 97%] Built target cocl | |
| Scanning dependencies of target run-cuda_sample | |
| [ 97%] CLANG_HOME=/usr/local/opt/llvm-4.0 /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/bin/cocl -DUSE_CLEW -I;/Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/CLBlast/src;-I;/Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/CLBlast/src /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/test/cocl/cuda_sample.cu -o cuda_sample.o -c --devicell-opt;O2 | |
| CLANG_HOME /usr/local/opt/llvm-4.0 | |
| + /usr/local/opt/llvm-4.0/bin/clang++ -DUSE_CLEW -DUSE_CLEW -std=c++11 -x cuda --cuda-gpu-arch=sm_30 -nocudalib -nocudainc --cuda-device-only -emit-llvm -O0 -S -stdlib=libc++ -I/usr/local/opt/llvm-4.0/include -D__STDC_CONSTANT_MACROS -D__STDC_FORMAT_MACROS -D__STDC_LIMIT_MACROS -I/usr/local/opt/llvm-4.0/include -fPIC -fvisibility-inlines-hidden -Wall -W -Wno-unused-parameter -Wwrite-strings -Wcast-qual -Wmissing-field-initializers -pedantic -Wno-long-long -Wcovered-switch-default -Wnon-virtual-dtor -Wdelete-non-virtual-dtor -Wstring-conversion -Werror=date-time -std=c++11 -O3 -fexceptions -D__STDC_CONSTANT_MACROS -D__STDC_FORMAT_MACROS -D__STDC_LIMIT_MACROS -I/Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/EasyCL -I/Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl -I/Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src -I/Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/EasyCL -I/Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/EasyCL/thirdparty/clew/include -include /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h -include /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/fake_funcs.h -include /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl_deviceside.h -I/Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include -I/Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/CLBlast/src -I/Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/CLBlast/src /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/test/cocl/cuda_sample.cu -o ./cuda_sample-device-noopt.ll | |
| In file included from <built-in>:1: | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:4:9: warning: defining device | |
| and host [-W#pragma-messages] | |
| #pragma message("defining device and host") | |
| ^ | |
| 1 warning generated. | |
| + /usr/local/opt/llvm-4.0/bin/opt -O2 -S -o ./cuda_sample-device.ll ./cuda_sample-device-noopt.ll | |
| + /usr/local/opt/llvm-4.0/bin/clang++ -DUSE_CLEW -I/Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/CLBlast/src -I/Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/CLBlast/src -DUSE_CLEW -std=c++11 -x cuda -nocudalib -nocudainc --cuda-host-only -emit-llvm -O3 -S -I/usr/local/opt/llvm-4.0/include -D__STDC_CONSTANT_MACROS -D__STDC_FORMAT_MACROS -D__STDC_LIMIT_MACROS -I/usr/local/opt/llvm-4.0/include -fPIC -fvisibility-inlines-hidden -Wall -W -Wno-unused-parameter -Wwrite-strings -Wcast-qual -Wmissing-field-initializers -pedantic -Wno-long-long -Wcovered-switch-default -Wnon-virtual-dtor -Wdelete-non-virtual-dtor -Wstring-conversion -Werror=date-time -std=c++11 -O3 -fexceptions -D__STDC_CONSTANT_MACROS -D__STDC_FORMAT_MACROS -D__STDC_LIMIT_MACROS -I/Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include -I/Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/EasyCL -I/Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl -I/Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src -I/Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/EasyCL/thirdparty/clew/include -I/Users/hugh2/git-local/tensorflow-blas/third_party/coriander/src/EasyCL -stdlib=libc++ -I/usr/local/opt/llvm-4.0/include -D__STDC_CONSTANT_MACROS -D__STDC_FORMAT_MACROS -D__STDC_LIMIT_MACROS -I/usr/local/opt/llvm-4.0/include -fPIC -fvisibility-inlines-hidden -Wall -W -Wno-unused-parameter -Wwrite-strings -Wcast-qual -Wmissing-field-initializers -pedantic -Wno-long-long -Wcovered-switch-default -Wnon-virtual-dtor -Wdelete-non-virtual-dtor -Wstring-conversion -Werror=date-time -std=c++11 -O3 -fexceptions -D__STDC_CONSTANT_MACROS -D__STDC_FORMAT_MACROS -D__STDC_LIMIT_MACROS -include /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h -include /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/fake_funcs.h -include /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl_hostside.h /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/test/cocl/cuda_sample.cu -o ./cuda_sample-hostraw.ll | |
| clang-4.0: warning: argument unused during compilation: '-nocudalib' [-Wunused-command-line-argument] | |
| In file included from <built-in>:1: | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:4:9: warning: defining device | |
| and host [-W#pragma-messages] | |
| #pragma message("defining device and host") | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:23:9: warning: '__host__' | |
| macro redefined [-Wmacro-redefined] | |
| #define __host__ | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:6:9: note: previous | |
| definition is here | |
| #define __host__ __attribute__((host)) | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:24:9: warning: '__device__' | |
| macro redefined [-Wmacro-redefined] | |
| #define __device__ | |
| ^ | |
| /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/include/cocl/cocl.h:5:9: note: previous | |
| definition is here | |
| #define __device__ __attribute__((device)) | |
| ^ | |
| 3 warnings generated. | |
| + /Users/hugh2/git-local/tensorflow-blas/third_party/coriander/build/patch_hostside --hostrawfile ./cuda_sample-hostraw.ll --devicellfile ./cuda_sample-device.ll --hostpatchedfile ./cuda_sample-hostpatched.ll | |
| patching main | |
| + /usr/local/opt/llvm-4.0/bin/clang++ -DUSE_CLEW -I/usr/local/opt/llvm-4.0/include -D__STDC_CONSTANT_MACROS -D__STDC_FORMAT_MACROS -D__STDC_LIMIT_MACROS -I/usr/local/opt/llvm-4.0/include -fPIC -fvisibility-inlines-hidden -Wall -W -Wno-unused-parameter -Wwrite-strings -Wcast-qual -Wmissing-field-initializers -pedantic -Wno-long-long -Wcovered-switch-default -Wnon-virtual-dtor -Wdelete-non-virtual-dtor -Wstring-conversion -Werror=date-time -std=c++11 -O3 -fexceptions -D__STDC_CONSTANT_MACROS -D__STDC_FORMAT_MACROS -D__STDC_LIMIT_MACROS -DUSE_CLEW -c ./cuda_sample-hostpatched.ll -O3 -o ./cuda_sample.o | |
| clang-4.0: warning: argument unused during compilation: '-I /usr/local/opt/llvm-4.0/include' [-Wunused-command-line-argument] | |
| clang-4.0: warning: argument unused during compilation: '-I /usr/local/opt/llvm-4.0/include' [-Wunused-command-line-argument] | |
| + '[' '!' 1 ']' | |
| [100%] Generating cuda_sample | |
| make run-cuda_sample | |
| CoclDevice::CoclDevice gpuOrdinal=0 | |
| OpenCL platform: Apple | |
| OpenCL device: AMD Radeon Pro 450 Compute Engine | |
| [COCL] cudaMalloc using cl, size 4096 memory=0x7fe2e0d03380 fakePos=128 | |
| setKernelArgGpuBuffer offset=0 elementSize=4 | |
| setKernelArgInt32 2 | |
| setKernelArgFloat 123 | |
| kernel_dumper toCl() _ZL21__nvvm_reflect_anchorv => _ZL21__nvvm_reflect_anchorv | |
| called function: [llvm.nvvm.read.ptx.sreg.tid.x] | |
| float addrspace(1)* | |
| built kernel _Z8setValuePfif_0 | |
| .. kernel queued | |
| [COCL] cudamempcy using opencl cudaMemcpyKind 111 count=16 | |
| hostFloats[2] 123 | |
| setKernelArgGpuBuffer offset=0 elementSize=4 | |
| setKernelArgInt32 2 | |
| setKernelArgFloat 222 | |
| .. kernel queued | |
| [COCL] cudamempcy using opencl cudaMemcpyKind 111 count=16 | |
| hostFloats[2] 222 | |
| [COCL] cudamempcy using opencl cudaMemcpyKind 222 count=16 | |
| [COCL] cudamempcy using opencl cudaMemcpyKind 111 count=16 | |
| hostFloats[2] 444 | |
| [COCL] cudafree using opencl memory=0x7fe2e0d03380 | |
| [100%] Built target run-cuda_sample |
Sign up for free
to join this conversation on GitHub.
Already have an account?
Sign in to comment